.. _spkg_json5:

json5: Python implementation of the JSON5 data format
===============================================================

Description
-----------

Python implementation of the JSON5 data format

License
-------

Apache

Upstream Contact
----------------

https://pypi.org/project/json5/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    0.9.14

version_requirements.txt::

    json5


Equivalent System Packages
--------------------------

(none known)

